Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3286)

Unified Diff: chrome/browser/ui/cocoa/browser_window_layout.mm

Issue 2467833003: [Mac] Move the fullscreen toolbar style to FullscreenToolbarController (Closed)
Patch Set: fix for rsesek Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/browser_window_layout.mm
diff --git a/chrome/browser/ui/cocoa/browser_window_layout.mm b/chrome/browser/ui/cocoa/browser_window_layout.mm
index 153a8d5610b1de49bcea3c88e141e6c34859fcfc..b9dc6328d96078f6ed13db66fb3950db546c4192 100644
--- a/chrome/browser/ui/cocoa/browser_window_layout.mm
+++ b/chrome/browser/ui/cocoa/browser_window_layout.mm
@@ -99,8 +99,8 @@ const CGFloat kLocationBarRightOffset = 35;
parameters_.inAnyFullscreen = inAnyFullscreen;
}
-- (void)setSlidingStyle:(FullscreenSlidingStyle)slidingStyle {
- parameters_.slidingStyle = slidingStyle;
+- (void)setFullscreenToolbarStyle:(FullscreenToolbarStyle)style {
+ parameters_.toolbarStyle = style;
}
- (void)setFullscreenMenubarOffset:(CGFloat)menubarOffset {
@@ -312,12 +312,11 @@ const CGFloat kLocationBarRightOffset = 35;
output_.findBarMaxY = maxY;
if (parameters_.inAnyFullscreen &&
- (parameters_.slidingStyle ==
- FullscreenSlidingStyle::OMNIBOX_TABS_HIDDEN ||
- parameters_.slidingStyle == FullscreenSlidingStyle::OMNIBOX_TABS_NONE)) {
- // If in presentation mode, reset |maxY| to top of screen, so that the
- // floating bar slides over the things which appear to be in the content
- // area.
+ (parameters_.toolbarStyle == FullscreenToolbarStyle::TOOLBAR_HIDDEN ||
+ parameters_.toolbarStyle == FullscreenToolbarStyle::TOOLBAR_NONE)) {
+ // If the toolbar is hidden or missing, reset |maxY| to top of screen, so
+ // that the toolbar slides over the things which appear to be in the
+ // content area.
maxY = parameters_.windowSize.height;
}
@@ -364,8 +363,7 @@ const CGFloat kLocationBarRightOffset = 35;
}
if (parameters_.inAnyFullscreen &&
- parameters_.slidingStyle ==
- FullscreenSlidingStyle::OMNIBOX_TABS_PRESENT) {
+ parameters_.toolbarStyle == FullscreenToolbarStyle::TOOLBAR_PRESENT) {
// If in Canonical Fullscreen, content should be shifted down by an amount
// equal to all the widgets and views at the top of the window. It should
// not be further shifted by the appearance/disappearance of the AppKit
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_layout.h ('k') | chrome/browser/ui/cocoa/browser_window_layout_unittest.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698